==> bow-ui-1.2-sources.jar: org/chorem/bow/BowPreference.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.ElementField;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public interface BowPreference extends BusinessEntity {

    String EXT_BOWPREFERENCE = "BowPreference";

    String FIELD_BOWPREFERENCE_TAGS = "tags";

    String FQ_FIELD_BOWPREFERENCE_TAGS = EXT_BOWPREFERENCE + ".tags";

    ElementField ELEMENT_FIELD_BOWPREFERENCE_TAGS = new ElementField(FQ_FIELD_BOWPREFERENCE_TAGS);

    String FIELD_BOWPREFERENCE_BOOKMARKS = "bookmarks";

    String FQ_FIELD_BOWPREFERENCE_BOOKMARKS = EXT_BOWPREFERENCE + ".bookmarks";

    ElementField ELEMENT_FIELD_BOWPREFERENCE_BOOKMARKS = new ElementField(FQ_FIELD_BOWPREFERENCE_BOOKMARKS);

    String FIELD_BOWPREFERENCE_COLORS = "colors";

    String FQ_FIELD_BOWPREFERENCE_COLORS = EXT_BOWPREFERENCE + ".colors";

    ElementField ELEMENT_FIELD_BOWPREFERENCE_COLORS = new ElementField(FQ_FIELD_BOWPREFERENCE_COLORS);

    int getTags();

    void setTags(int tags);

    int getBookmarks();

    void setBookmarks(int bookmarks);

    String getColors();

    void setColors(String colors);

} //BowPreference

==> bow-ui-1.4.1-sources.jar: org/chorem/bow/BowPreference.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.ElementField;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public interface BowPreference extends BusinessEntity {

    String EXT_BOWPREFERENCE = "BowPreference";

    String FIELD_BOWPREFERENCE_TAGS = "tags";

    String FQ_FIELD_BOWPREFERENCE_TAGS = EXT_BOWPREFERENCE + ".tags";

    ElementField ELEMENT_FIELD_BOWPREFERENCE_TAGS = new ElementField(FQ_FIELD_BOWPREFERENCE_TAGS);

    String FIELD_BOWPREFERENCE_BOOKMARKS = "bookmarks";

    String FQ_FIELD_BOWPREFERENCE_BOOKMARKS = EXT_BOWPREFERENCE + ".bookmarks";

    ElementField ELEMENT_FIELD_BOWPREFERENCE_BOOKMARKS = new ElementField(FQ_FIELD_BOWPREFERENCE_BOOKMARKS);

    String FIELD_BOWPREFERENCE_COLORS = "colors";

    String FQ_FIELD_BOWPREFERENCE_COLORS = EXT_BOWPREFERENCE + ".colors";

    ElementField ELEMENT_FIELD_BOWPREFERENCE_COLORS = new ElementField(FQ_FIELD_BOWPREFERENCE_COLORS);

    String FIELD_BOWPREFERENCE_SCREENSHOT = "screenshot";

    String FQ_FIELD_BOWPREFERENCE_SCREENSHOT = EXT_BOWPREFERENCE + ".screenshot";

    ElementField ELEMENT_FIELD_BOWPREFERENCE_SCREENSHOT = new ElementField(FQ_FIELD_BOWPREFERENCE_SCREENSHOT);

    String FIELD_BOWPREFERENCE_FAVICON = "favicon";

    String FQ_FIELD_BOWPREFERENCE_FAVICON = EXT_BOWPREFERENCE + ".favicon";

    ElementField ELEMENT_FIELD_BOWPREFERENCE_FAVICON = new ElementField(FQ_FIELD_BOWPREFERENCE_FAVICON);

    int getTags();

    void setTags(int tags);

    int getBookmarks();

    void setBookmarks(int bookmarks);

    String getColors();

    void setColors(String colors);

    Boolean getScreenshot();

    void setScreenshot(Boolean screenshot);

    Boolean getFavicon();

    void setFavicon(Boolean favicon);

} //BowPreference
